require 'spec_helper'
require 'static_maps'

describe 'Params' do
  let(:params)    { StaticMaps::Params }
  let(:base_url)  { params::BASE_URL }
  let(:defaults)  { params::DEFAULTS }
  let(:allowed)   { params::ALLOWED }

  describe 'base url' do
    it { base_url.should eq 'http://maps.googleapis.com/maps/api/staticmap' }
  end

  describe 'defaults' do
    it { defaults.frozen?.should eq true }
    it { defaults.should include :visual_refresh }
    it { defaults.should include :center }
    it { defaults.should include :size }
    it { defaults.should include :sensor }
    it { defaults.should include :zoom }
  end

  describe 'allowed' do
    let(:filtered_params){
      params.filter_allowed({:scale => 2, :invalid => false })
    }

    it { allowed.frozen?.should eq true }
    it { filtered_params.should include :zoom }
    it { filtered_params.should_not include :invalid }
  end

  describe 'build url' do
    let(:url) {
      params.build_url({:center => 'City Hall, New York, NY',
                        :markers => 'color:red|City Hall, New York, NY'})
    }

    it { url.should include base_url }
    it { url.should include 'City+Hall,+New+York,+NY' }
    it { url.should_not include ' ' }
    it { url.should include 'color:red%7CCity+Hall,+New+York,+NY' }
    it { url.should_not include '|' }
  end

end

