require 'spec_helper'
require 'static_maps'

describe 'Param Validation' do
  let(:params) { StaticMaps::Params }
  let(:valids) { StaticMaps::Validations }

  describe 'Visual Refresh and Sensor' do
    it 'should permit boolean values' do
      valids.validate(:visual_refresh, true).should eq true
      valids.validate(:sensor, false).should eq false
    end
    it 'should permit string values' do
      valids.validate(:visual_refresh, 'true').should eq true
      valids.validate(:sensor, 'FalSE').should eq false
    end
    it 'should fallback to opinionated default' do
      valids.validate(:visual_refresh, 'yes').should eq true
      valids.validate(:sensor, nil).should eq false
    end
  end

  describe 'Size' do
    it 'should extract regex pattern /\n+x\n+/' do
      valids.validate(:size, '300x300').should eq '300x300'
      valids.validate(:size, 'bad300x300 bad').should eq '300x300'
    end
    it 'should take single value or non-zero value' do
      valids.validate(:size, '300').should eq '300x300'
      valids.validate(:size, 'x300').should eq '300x300'
      valids.validate(:size, '-100x - 300').should eq '100x300'
    end
    it 'should fallback to max size' do
      valids.validate(:size, '').should eq '640x640'
      pending 'test for zero values i.e. 0, 0x0, 00x0000'
    end
  end

  describe 'Scale' do
    it 'should permit 1 or 2 numbers' do
      valids.validate(:scale,1).should eq 1
      valids.validate(:scale,2).should eq 2
    end
    it 'should permit 1 or 2 string' do
      valids.validate(:scale,"1").should eq 1
      valids.validate(:scale,"2").should eq 2
    end
    it 'should fallback to 1' do
      valids.validate(:scale,"0").should eq 1
      valids.validate(:scale,"").should eq 1
      valids.validate(:scale,"bad").should eq 1
    end
  end

  describe 'Zoom' do
    it 'should permit numbers' do
      valids.validate(:zoom,16).should eq 16
    end
    it 'should permit strings' do
      valids.validate(:zoom,'16').should eq 16
    end
    it 'should fallback to zoom=12' do
      valids.validate(:zoom,'').should eq 12
      valids.validate(:zoom,'bad').should eq 12
    end
  end

  describe 'Format' do
    it 'should permit string' do
      valids.validate(:format,'gif').should eq 'gif'
    end
    it 'should fallback to png' do
      valids.validate(:format,'badgif').should eq 'png'
      valids.validate(:format,false).should eq 'png'
    end
  end

  describe 'Map Type' do
    it 'should permit string' do
      valids.validate(:maptype,'terrain').should eq 'terrain'
    end
    it 'should fallback to roadmap' do
      valids.validate(:maptype,'badtype').should eq 'roadmap'
      valids.validate(:maptype,false).should eq 'roadmap'
    end
  end

  pending 'center (lat/long or loc) - comma delimit'
  pending 'marker {size{tiny, mid, small}, color{HEX/basic}, label {A-Z0-9}}'
  pending 'style, paths, & complex markers...TBD'
end
